@@ -25,7 +25,7 @@ def initialize_credentials(conn_id=default_google_conn_id):
     You still need to share spreadsheets with the service account email.
     """
     
-    credentials = GoogleBaseHook(conn_id)._get_credentials()
+    credentials = GoogleBaseHook(conn_id).get_credentials()
     return credentials
 
 def create_slides(conn_id=default_google_conn_id, credentials=None):
